@@ -11,14 +11,16 @@ class Logger:
 
     _SUPPORTED_LEVELS: list = list(LogLevel)
 
-    def __init__(self, name: str = "Root-Logger",
+    def __init__(self, name: str,
                  time_format: str = None,
                  min_loglevel: LogLevel = LogLevel.INFO,
                  max_loglevel: LogLevel = LogLevel.CRITICAL) -> None:
 
         self.name: str = name
-        self.min_loglevel: LogLevel = min_loglevel
-        self.max_loglevel: LogLevel = max_loglevel
+        self.min_loglevel: LogLevel = min_loglevel \
+            if min_loglevel in LogLevel else LogLevel.INFO
+        self.max_loglevel: LogLevel = max_loglevel \
+            if max_loglevel in LogLevel else LogLevel.CRITICAL
 
         self.handlers: list[Handler] = []
 
@@ -63,7 +65,7 @@ class Logger:
             bool: True if the log level is under the maximum, False otherwise.
         """
         return self._SUPPORTED_LEVELS.index(loglevel) <= \
-            self._SUPPORTED_LEVELS.index(self.min_loglevel)
+            self._SUPPORTED_LEVELS.index(self.max_loglevel)
 
     def _get_iso_8601_timestamp(self) -> str:
         """
@@ -98,11 +100,11 @@ class Logger:
             dict: A dictionary containing the formatted log message.
         """
         values = {
-            "message": message,
-            "loglevel": loglevel.name,
-            "asctime": self._get_timestamp(),
-            "iso_8601_time": self._get_iso_8601_timestamp(),
             "loggername": self.name,
+            "iso_8601_time": self._get_iso_8601_timestamp(),
+            "asctime": self._get_timestamp(),
+            "loglevel": loglevel.name,
+            "message": message,
         }
         return values
 
